C  *DECK CDTR
C
C     ..................................................................
C
C        SUBROUTINE CDTR
C
C        PURPOSE
C           COMPUTES P(CHISQ) = PROBABILITY THAT THE RANDOM VARIABLE U,
C           DISTRIBUTED ACCORDING TO THE CHI-SQUARE DISTRIBUTION WITH G
C           DEGREES OF FREEDOM, IS LESS THAN OR EQUAL TO CHISQ.  F(G,CHI
C           ORDINATE OF THE CHI-SQUARE DENSITY AT CHISQ, IS ALSO COMPUTE
C
C        USAGE
C           CALL CDTR(CHISQ,IDF,SIGCHI,IER)
C
C        DESCRIPTION OF PARAMETERS
C           CHISQ   - INPUT SCALAR FOR WHICH P(CHISQ) IS COMPUTED.
C           IDF     - NUMBER OF DEGREES OF FREEDOM OF THE CHI-SQUARE
C                     DISTRIBUTION.  IDF IS AN INTEGER.
C           SIGCHI  - OUTPUT PROBABILITY.
C           IER     - RESULTANT ERROR CODE WHERE
C               IER= 0 --- NO ERROR
C               IER=-1 --- AN INPUT PARAMETER IS INVALID.  X IS LESS
C                          THAN 0.0, OR IDF IS LESS THAN 0.0 OR GREATER
C                          THAN 2*10**(+5).  P AND D ARE SET TO -1.E25.
C               IER=-2 --- IDF = 0, P SET TO 0.
C               IER=+1 --- INVALID OUTPUT.  P IS LESS THAN ZERO OR
C                          GREATER THAN ONE, OR SERIES FOR T1 (SEE
C                          MATHEMATICAL DESCRIPTION) HAS FAILED TO
C                          CONVERGE.  P IS SET TO 1.E25.
C
C        SUBROUTINES AND FUNCTION SUBPROGRAMS REQUIRED
C           NDTR
C
C        METHOD
C
C     THIS FUNCTION WAS LIFTED FROM "NWAY" WRITTEN BY THE STANFORD
C     COMPUTATION CENTER. THE SCC BORROWED IT FROM JOHN MORRIS OF THE
C     COMPUTER INSTITUTE FOR SOCIAL SCIENCE RESEARCH AT MICHIGAN STATE
C     UNIVERSITY.
C
      SUBROUTINE CDTR (CHISQ,IDF,SIGCHI,IER)
      INTEGER IDF, IER
      DOUBLE PRECISION CHISQ, SIGCHI
      DOUBLE PRECISION FACT(0:30), ANSCHI, FF, P, XI, PP, TERM, ARGNRM,
     1 GAM, TXX
      INTEGER I
C
C     FACTORIALS OF 0 THROUGH 30. .
      DATA FACT /1.00000000000000D00,1.00000000000000D00,2.000000
     1 00000000D00,6.00000000000000D00,2.40000000000000D01,1.20000000000
     2 000D02,7.20000000000000D02,5.04000000000000D03,4.03200000000000D0
     3 4,3.62880000000000D05,3.62880000000000D06,3.99168000000000D07,4.7
     4 9001600000000D08,6.22702080000000D09,8.71782912000000D10,1.307674
     5 36800000D12,2.09227898880000D13,3.55687428096000D14,6.40237370572
     6 800D15,1.21645100408832D17,2.43290200817664D18,5.10909421717094D1
     7 9,1.12400072777761D21,2.58520167388850D22,6.20448401733239D23,1.5
     8 5112100433310D25,4.03291461126606D26,1.08888694504184D28,3.048883
     9 44611714D29,8.84176199373970D30,2.65252859812191D32/
C
      IER=0
      ANSCHI=1.
      IF (CHISQ.LT.0..OR.IDF.LT.0) THEN
         IER=-1
         SIGCHI=-1.D25
      ELSE IF (IDF.EQ.0) THEN
         IER=0
         SIGCHI=0.
      ELSE IF (CHISQ+100..EQ.100.) THEN
         IER=0
         SIGCHI=0.
      ELSE
C
C     GT 60 D.F. OR CHI GT 100 - USE A NORMAL APPROXIMATION
         IF (IDF.GT.60 .OR. CHISQ.GT.100.) THEN
            ARGNRM=SQRT(2.D0*CHISQ)-SQRT(2.D0*DBLE(IDF)-1.D0)
            CALL NDTR (ARGNRM,SIGCHI)
         ELSE
            FF=IDF-2
            P=0.5*FF
            XI=0.5*CHISQ
            PP=P+2.0
            TERM=XI/PP
            DO 10 I=1,100
            ANSCHI=ANSCHI+TERM
            IF (ABS(TERM).LT.1.0D-6) GO TO 20
            PP=PP+1.0
   10       TERM=TERM*XI/PP
   20       GAM=1.0
            IF (MOD(IDF,2).EQ.0) THEN
               GAM=FACT(IDF/2)
            ELSE
   30          DO 40 I=1,IDF,2
   40          GAM=GAM*DBLE(I)*0.5D0
               GAM=GAM*1.7724588509
            ENDIF
            TXX=(P+1.0)*LOG(XI)- XI + LOG(ANSCHI/GAM)
            IF (TXX.LE.88.0) THEN
               IF (TXX.GT.-88.0) THEN
                  ANSCHI=EXP(TXX)
               ELSE
                  ANSCHI=0.
              ENDIF
            ELSE
               ANSCHI=1.
            ENDIF
C           IF (ANSCHI.LT.0.) THEN
C              ANSCHI=0.
C           ELSEIF (ANSCHI.GT.1.) THEN
C              ANSCHI=1.
C           ENDIF
            SIGCHI=ANSCHI
         ENDIF
         IF (SIGCHI.LT.0..OR.SIGCHI.GT.1.) THEN
            IER=1
            SIGCHI=1.D25
         ENDIF
      ENDIF
      RETURN
      END
