C  *DECK NDTR
C        SUBROUTINE NDTR
C
C        PURPOSE
C           COMPUTES Y = P(X) = PROBABILITY THAT THE RANDOM VARIABLE  U,
C           DISTRIBUTED NORMALLY(0,1), IS LESS THAN OR EQUAL TO X.
C           F(X), THE ORDINATE OF THE NORMAL DENSITY AT X, IS ALSO
C           COMPUTED.
C
C        USAGE
C           CALL NDTR(X,P)
C
C        DESCRIPTION OF PARAMETERS
C           X--INPUT SCALAR FOR WHICH P(X) IS COMPUTED.
C           P--OUTPUT PROBABILITY.
C
C        REMARKS
C           MAXIMUM ERROR IS 0.0000007.
C
C        SUBROUTINES AND SUBPROGRAMS REQUIRED
C           NONE
C
C        METHOD
C           BASED ON APPROXIMATIONS IN C. HASTINGS, APPROXIMATIONS FOR
C           DIGITAL COMPUTERS, PRINCETON UNIV. PRESS, PRINCETON, N.J.,
C           1955.  SEE EQUATION 26.2.17, HANDBOOK OF MATHEMATICAL
C           FUNCTIONS, ABRAMOWITZ AND STEGUN, DOVER PUBLICATIONS, INC.,
C           NEW YORK.
C
C     ******************************************************************
C
      SUBROUTINE NDTR (X,P)
      DOUBLE PRECISION X,P,T,D
C
      T=1.D0/(1.D0+.2316419D0*ABS(X))
      IF (-X*X*0.5D0.LT.-700.D0) THEN
         D=0.3989423D0*EXP(-700.D0)
      ELSE
         D=0.3989423D0*EXP(-X*X*0.5D0)
      ENDIF
      P=1.0D0-D*T*((((1.330274D0*T-1.821256D0)*T+1.781478D0)*T
     1 -0.3565638D0)*T+0.3193815D0)
      IF (X .LT. 0.D0) THEN
         P=1.D0-P
      ENDIF
   20 RETURN
      END
